@@ -398,7 +398,12 @@ sub connect_database {
 			$@ = qq{Could not open "$conf": $!};
 			last GETHANDLE; ## Fail - no conf file
 		}
-		print $cfh "\n\n## DBD::Pg testing parameters\nport=$testport\nmax_connections=4\n";
+		print $cfh "\n\n## DBD::Pg testing parameters\n";
+		print $cfh "port=$testport\n";
+		print $cfh "max_connections=4\n";
+		print $cfh "log_statement = 'all'\n";
+		print $cfh "log_line_prefix = '%m [%p] '\n";
+		print $cfh "log_min_messages = 'DEBUG1'\n";
 		print $cfh "listen_addresses='127.0.0.1'\n" if $^O =~ /Win32/;
 		print $cfh "\n";
 		close $cfh or die qq{Could not close "$conf": $!\n};
